@@ -1,14 +1,17 @@
-#include <stdio.h>
+//#include <stdio.h>
+#include <cstdio>
 #include <iostream>
-#include <math.h>
-#include <stdlib.h>
+//#include <math.h>
+#include <cmath>
+//#include <stdlib.h>
+#include <cstdlib>
 
 #include "Rlob.h"
 
-extern "C" {
+//extern "C" {
 #include <R.h>
 #include <Rmath.h>
-};
+//};
 
 typedef double *dp;
 typedef int *ip;
