@@ -1,15 +1,18 @@
 #ifndef GUARD_Rlob
 #define GUARD_Rlob
 
-#include <stdio.h>
+//#include <stdio.h>
+#include <cstdio>
 #include <iostream>
-#include <math.h>
-#include <stdlib.h>
+//#include <math.h>
+#include <cmath>
+//#include <stdlib.h>
+#include <cstdlib>
 
-extern "C" {
+//extern "C" {
 #include <R.h>
 #include <Rmath.h>
-};
+//};
 
 typedef double *dp;
 typedef int *ip;
